##  Inserting a Report into a Confluence Page
To insert an SAP LeanIX report to a Confluence page, follow these steps:
  1. Choose + > Other Macros > SAP LeanIX. You can find it under External content or by using the search field.![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274da1557a4410148dead0806e213cb0_LowRes.png)
  2. On the Report tab, select the desired report. You’ll see a live preview of your report in the configuration window. ![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2754493d7a44101499b7dd7df303ac4c_LowRes.png)
  3. Optional: Adjust the width and height. By default, the height is set to 600px and the width is set to 100%.
  4. Choose Insert to embed the report in your Confluence page.
